Documentation
¶
Index ¶
Constants ¶
const ( DefaultModel = "gemini-2.5-pro-preview-03-25" GeminiAPIKeyEnv = "GEMINI_API_KEY" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service struct {
HTTPC *http.Client // defaults to http.DefaultClient if nil
URL string // Gemini API URL, uses the gemini package default if empty
APIKey string // must be non-empty
Model string // defaults to DefaultModel if empty
DumpLLM bool // whether to dump request/response text to files for debugging; defaults to false
}
Service provides Gemini completions. Fields should not be altered concurrently with calling any method on Service.
func (*Service) TokenContextWindow ¶
TokenContextWindow returns the maximum token context window size for this service
Click to show internal directories.
Click to hide internal directories.